@@ -51,9 +51,12 @@ class Message:
                  info_level = 4,
                  warn_level = 4,
                  col = True,
-                 mth = ['*'],
-                 obj = ['*'],
-                 var = ['*']):
+                 mth = None,
+                 obj = None,
+                 var = None):
+        if mth == None: mth = ['*']
+        if obj == None: obj = ['*']
+        if var == None: var = ['*']
 
         # A description of the module that is being debugged
         self.debug_env = module
@@ -107,7 +110,7 @@ class Message:
         group = OptionGroup(parser,
                             '<Debugging options>',
                             'Control the debugging features of '
-			    + self.debug_env)
+                            + self.debug_env)
 
         group.add_option('--debug',
                          action = 'store_true',
